@@ -3,19 +3,20 @@
 set -e
 set -x
 
-autoreconf --install
+autoreconf -vfi
 chmod +x configure
 
 case "$target_platform" in
     linux*|osx*)
+        # Get an updated config.sub and config.guess
+        cp $BUILD_PREFIX/share/gnuconfig/config.* ./cnf
         export CFLAGS="-O3 -g -fPIC $CFLAGS"
-        ./configure --prefix=$PREFIX --with-e-antic=$PREFIX --with-nauty=$PREFIX --with-flint=$PREFIX --with-gmp=$PREFIX
+        ./configure --prefix=$PREFIX --with-e-antic=$PREFIX --with-nauty=$PREFIX --with-flint=$PREFIX --with-gmp=$PREFIX || (cat config.log; false)
         ;;
     win*)
         cp $PREFIX/lib/gmp.lib $PREFIX/lib/gmpxx.lib
         sed -i.bak "s/-Wl,-rpath,/-L/g" configure
-        # https://github.com/Normaliz/Normaliz/pull/353/files
-        echo -e "#include <ctime>\n$(cat source/maxsimplex/maxsimplex.cpp)" > source/maxsimplex/maxsimplex.cpp
+		sed -i.bak "s@#include <sys/time.h>@@g" source/libnormaliz/full_cone.h
         ./configure --prefix="$PREFIX" --with-nauty=$PREFIX --with-gmp="$PREFIX" || (cat config.log; false)
         patch_libtool
         echo $?
@@ -24,10 +25,12 @@ esac
 
 make -j${CPU_COUNT}
 echo $?
-if [[ "$PKG_VERSION" == "3.8.5" ]]; then
-  make check -j${CPU_COUNT} || true;
-else
-  make check -j${CPU_COUNT}
+if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
+  if [[ "$target_platform" = linux-* ]]; then
+    make check -j${CPU_COUNT} -k
+  else
+    make check -j${CPU_COUNT} -k || true;
+  fi
 fi
 make install
 echo $?
